#! /bin/sh

# This script is intended to change the media-directory 
# along with the links to network shares
# links to shares on the old media-directory is deleted first
# then media directory is changed followed by links creation
# also .update is touched at the end

# Read system configuration file if it is present
[ -r /etc/default/sysconfig ] && . /etc/default/sysconfig

. /etc/default/globals

HDMP=/media/hd
NFS_MP=/media/nfs
NETWORK_RECORDING=false

HasLocalHD () {
# TODO: do a real test if it is a HD (speed, size...)
#       do *not* test the mountpoint but the device...
# size is larger than 100M
    [ `df $HDMP 2>/dev/null | tail -n 1 | awk '{print $2}'` -gt 102400 ]
}

### copy-pasted from /etc/init.d/reelvdr
prepare_mediadrive ()
{
#set -x
    # last resort
    MEDIADIR=/tmp
    RECORDINGSDIR=$MEDIADIR/recordings

    if [ ! -z "$MEDIADEVICE" ]; then
        MP=/media/reel
        if [ "$MEDIADEVICE_ONLY_RECORDING" = "yes" ]; then
            if HasLocalHD ; then
                echo "HAS local HD"
                MP=$HDMP/recordings  # /media/hd
                MEDIADIR=$HDMP
                RECORDINGSDIR=$MP
            else
                echo "no local HD"
                # overwrites MEDIADEVICE_ONLY_RECORDING!
                Syslog "Error: there is no valid MEDIADIR. Using RECORDING-dir as MEDIADIR."
                MEDIADIR=$MP
                RECORDINGSDIR=$MEDIADIR/recordings
            fi
        else
            MEDIADIR=$MP
            RECORDINGSDIR=$MEDIADIR/recordings
        fi
        # already mounted?
        if echo $MEDIADEVICE | grep -q UUID ; then
            # MEDIADEVICE is in the form UUID=... so we have to find the real devicename
            eval $MEDIADEVICE
            MEDIADEVICE="/dev/$(ls -l /dev/disk/by-uuid/$UUID | cut -f2 -d">" | cut -f 3 -d/)"
        fi
        MMP=`grep "$MEDIADEVICE" /proc/mounts | head -n 1 | cut -f2 -d" "`
        if [ -z "$MMP" ] ; then
            # not mounted
            echo n | fsck -y "$MEDIADEVICE" # TODO: only for local devices
            [ -d $MP ] || install -d -m 000 $MP/recordings
            if ! mount "$MEDIADEVICE" $MP/ ; then
                # mount failed, look for local HD
                if HasLocalHD ; then
                    MEDIADIR=$HDMP
                else
                    MEDIADIR=/tmp
                fi
                RECORDINGSDIR=$MEDIADIR/recordings
                Syslog "WARNING: Mounting $MEDIADEVICE failed. Using $RECORDINGSDIR as last resort"
            fi
        else
            # mounted
            if [ "$MEDIADEVICE_ONLY_RECORDING" = "yes" ]; then
                MEDIADIR=/media/hd
                RECORDINGSDIR=$MMP
                [ -d "$RECORDINGSDIR/recordings" ] && RECORDINGSDIR="$RECORDINGSDIR/recordings"
            else
                MEDIADIR=$MMP
                RECORDINGSDIR=$MEDIADIR/recordings
            fi
        fi
    else
        # old behaviour, for later removal (rm @ 08.04.2009)
        #set RECORDING_HD in sysconfig
        HD=$RECORDING_HD
        #TODO:  NetClient: check if we have a local HD and mount it before
        #       check if this is a real hd (size, speed?) before creating /recordings
        #   check for external/network drives
        [ -z $HD ] && HD="sda4"

        #already mouted to MP?
        if grep -q /dev/$HD /proc/mounts ; then
            MEDIADIR=$HDMP
            RECORDINGSDIR="$HDMP/recordings"
        else
            Syslog "WARNING: No harddisk found or wrong device in sysconfig. Using $RECORDINGSDIR as last resort"
        fi

        if [ ! -d $RECORDINGSDIR ]; then
            install -d $RECORDINGSDIR
        fi
    fi
    export MEDIADIR RECORDINGSDIR
    Syslog "MEDIADIR is $MEDIADIR, RECORDINGSDIR is $RECORDINGSDIR" 2>/dev/null
    echo "MEDIADIR=$MEDIADIR" > /tmp/.mediadir
    echo "RECORDINGSDIR=$RECORDINGSDIR" >> /tmp/.mediadir

    # check directory for pictures and music
    for dir in music pictures recordings video; do
        [ -d $MEDIADIR/$dir ] || install -d -m2775 -g ftpusers $MEDIADIR/$dir
        rm -f /media/reel/$dir
    done


    # link everything in place
    install -m 2775 -d /media/reel
    [ -d /media/reel/recordings ] || ln -sf $RECORDINGSDIR /media/reel/recordings
    for dir in music pictures video; do
        ln -sf $MEDIADIR/$dir /media/reel/
        done


    # Link network drives to the harddisk. This has to be done after the
    # mediadir/recordingsdir is set up and before reelvdr starts
    link-shares start


    # prepare tmp directories for filebrowser
    TMP_DIRS="/tmp/browsercache /var/cache/images"
    for i in $TMP_DIRS ; do
        [ -d "$i" ] || mkdir "$i"
    done

    # prepare tmp directory for dvdswitch
    mkdir -p /tmp/DVDROOT

}

# delete old links
link-shares stop

#change media drive and create new symlinks to network-drives/shares
prepare_mediadrive

#let vdr update its recordings
touch $RECORDINGSDIR/.update

