#!/bin/sh

###### Algo ######
# collect UUIDs belonging to $HDD
# unmount all partitions of device
# destroy partition table
# create new partition
# unmount all partition: because creating paritition triggers automount!
# format newly created partition
# remove old UUIDs and partitions from fstab
# trigger UUID update
# new UUID into fstab
# mount partition
# create media subdirectories
# create links to /media/reel # done by calling setup plugin's svdrp command CHMD


FSTAB=/etc/fstab
OLDUUIDLOG=/tmp/olduuid.$$.log
FORMAT_STATUS_LOG=/tmp/disk_format_status.log

syntax () {
cat << EOF
Usage: `basename $0` <filesystem> <hd device>
Options:
     filesystem: use one of: reiserfs | jfs
     hd device:  /dev/hdc or /dev/hdd

Description:
     Prepares unformatated HD for ReelBox
EOF
}



# unmounts a partition from all its mount points
# gives up after 10 tries
unmount_partition() { 
    PART=$1; 
    tries=0;
    while [ "$(mount | grep $PART)" ]; 
    do 
        umount  $PART; 
        #[ $? ] && ((tries++))
        tries=$(($tries+1));
        if [ $tries -ge 10 ]; then
            break;
        fi
    done;
}



#umount all partitions of a given device
# eg. unmount_all_partitions /dev/sdc
unmount_all_partitions(){
    echo "unmount all partitions : $1"
	#fdisk -l $1 | grep ^/dev | awk '{print $1}' | xargs -I '{}' unmount_paritition '{}'
	for p in $( fdisk -l $1 | grep ^/dev | awk '{print $1}' ) 
    do
        echo $p
        unmount_partition $p
    done
}




remove_from_fstab()
{
    UUIDLIST=$2
    HDD=$1

#    REMOVE_UUID=/tmp/remove_uuid.$$.sh
#cat > ${REMOVE_UUID} << EOF
#eval \$1
#sed 's%\${UUID}%%' -i $FSTAB
#EOF

#cat $UUIDLIST | cut -f2- -d':' | xargs -I '{}' sh $REMOVE_UUID '{}'
    for i in "$(cat $UUIDLIST | cut -f2- -d':')"
    do
        eval $i
        sed /$UUID/d -i $FSTAB
    done

    sed "\%${HDD}%d" -i $FSTAB

}


# returns 0 when "$1" directory is empty or non-existant
check_empty_dir ()
{
  num_entries=$(ls -1A "$1"|wc -l)
  return $num_entries
}

### Main

#set -x
echo "FORMAT_STATUS=\"ongoing\"" > $FORMAT_STATUS_LOG
if [ $# -lt 2 ] ; then
	syntax
	exit 1
fi

FS=$1
HDD=$2



# find a suitable mountpoint
MP=/media/hd1 

#find all mountpoints of type MEDIAHD
MEDIAHD="/media/hd"

# list directories already in use as mountpoints
MPs=$(mount | awk '{print $(NF-3)}' | grep ${MEDIAHD})


# find a unused directory of type ${MEDIAHD}$i (eg. /media/hd3)
# also the directory should be empty. 
# Note: the directory may not exist, which is fine with us.
for i in $(seq 1 20)
do
    echo "$0 : trying ${MEDIAHD}$i"
    
# check if ${MEDIAHD}$i is already mount, then to next iteration
# else if directory is empty OR doesnot exist the we have found our mountpoint. 
    echo $MPs | grep -q "${MEDIAHD}$i" || check_empty_dir ${MEDIAHD}$i && break
done

MP=${MEDIAHD}$i

#make sure mount point exists
mkdir -p "$MP"



#save old UUID and later remove it from fstab 
eval `blkid ${HDD}1 | cut -d' '  -f2- `
OLDUUID=$UUID
blkid | grep ^$HDD > $OLDUUIDLOG


#hdparm -d1 -q $HDD # hdparm not available on NetClient


#unmount all partitions of this device
#fdisk -l ${HDD} | grep ^/dev | awk '{print $1}' | xargs -I '{}' umount '{}'
unmount_all_partitions ${HDD}


# blank bootblock+partition table
dd if=/dev/zero of=${HDD} bs=512 count=1


# create new partition
echo -e "n\np\n1\n\n\nw\n" | fdisk ${HDD} #< /usr/share/reel/fdiskcommands


# partitioning triggers a mount!
# So, umount again
unmount_all_partitions ${HDD}



# format
MKFS=$(which mkfs.$FS)
nice -n 10 $MKFS -q ${HDD}1

#needs filesystem check, else the next boot takes too long ~10mins with 250GB hdd!
#fsck ${HDD}1


# UUID is refreshed after mkfs, 
# but there seems to be some talk about manual triggering of UUID refresh
# eg. symlinks here /dev/disk/by-uuid/ are not updated after mkfs: needs udevtrigger
# refresh UUID
# from http://www.racmar.com/content/view/26/42/
#blkid

# udevtrigger # only on Avg
# udevadm trigger # only on NetClient
# on NetClient "udevadm trigger" exists (but not on Avg)
partprobe # update partition table changes, from parted package available on both Avg and NetClient
sleep 10 # /dev/disk/by-uuid takes time to get updated on NetClient
# uuid update takes a while ~10secs!


# remove old entry from fstab
remove_from_fstab $HDD $OLDUUIDLOG


# new entry into fstab
eval `blkid ${HDD}1 | cut -d' '  -f2- `
[ -n "$UUID" ] && echo "UUID=$UUID	$MP	$FS defaults	0	0" >> $FSTAB 

mount ${HDD}1 $MP
#mount failed

#create media subdirectories
for i in images recordings music pictures video opt ; do
	install -d -m777 ${MP}/$i
done

## links to /media/reel
## change sysconfig's MEDIADEVICE
## call change_media_drive.sh 

svdrpsend.sh plug setup CHMD "UUID=$UUID"

# inform vdr to update its recordings list
#touch /media/reel/recordings/.update


echo "FORMAT_STATUS=\"complete\"" > $FORMAT_STATUS_LOG
